@@ -1,3 +1,12 @@
+## ---- eval=FALSE, echo=FALSE---------------------------------------------
+#  header-includes:
+#  - \usepackage{fancyhdr}
+#  - \pagestyle{fancy}
+#  - \fancyhead[CO,CE]{Propensity to Cycle Tool Training Course}
+#  - \fancyfoot[CO,CE]{For source code and support see github.com/ITSLeeds and github.com/npct}
+#  - \fancyfoot[LE,RO]{\thepage}
+#  output: pdf_document
+
 ## ---- include = FALSE----------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
@@ -10,9 +19,11 @@ knitr::opts_chunk$set(
 #  refs = RefManageR::ReadZotero(group = "418217", .params = list(collection = "JFR868KJ", limit = 100))
 #  refs2 = RefManageR::ReadBib("vignettes/refs.bib")
 #  refs = c(refs, refs2)
-#  citr::insert_citation(bib_file = "vignettes/refs_training.bib")
+#  refs_df = as.data.frame(refs)
+#  # View(refs_df)
+#  # citr::insert_citation(bib_file = "vignettes/refs_training.bib")
 #  RefManageR::WriteBib(refs, "vignettes/refs_training.bib")
-#  citr::tidy_bib_file(rmd_file = "vignettes/pct_training.Rmd", messy_bibliography = "vignettes/refs_training.bib")
+#  # citr::tidy_bib_file(rmd_file = "vignettes/pct_training.Rmd", messy_bibliography = "vignettes/refs_training.bib")
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  install.packages("remotes")
@@ -32,35 +43,56 @@ knitr::opts_chunk$set(
 ## ----testcode, eval = FALSE----------------------------------------------
 #  source("https://raw.githubusercontent.com/ITSLeeds/TDS/master/code-r/setup.R")
 
-## ----setup, out.width="100%", message=FALSE------------------------------
+## ----setup, out.width="30%", message=FALSE-------------------------------
 library(pct)
 library(dplyr)   # in the tidyverse
-library(leaflet) # installed alongside mapvew
-zones_all = get_pct_zones("west-yorkshire")
-lines_all = get_pct_lines("west-yorkshire")
+library(tmap) # installed alongside mapview
+region_name = "isle-of-wight"
+max_distance = 7
+zones_all = get_pct_zones(region_name)
+lines_all = get_pct_lines(region_name)
 # basic plot
 plot(zones_all$geometry)
 plot(lines_all$geometry[lines_all$all > 500], col = "red", add = TRUE)
-# interactive plot
+
+# create 'active' desire lines (less than 5 km)
 active = lines_all %>% 
   mutate(`Percent Active` = (bicycle + foot) / all * 100) %>% 
-  filter(e_dist_km < 5)
-pal = colorBin(palette = "RdYlBu", domain = active$`Percent Active`, bins = c(0, 2, 4, 10, 15, 20, 30, 40, 90))
-leaflet(data = active) %>% 
-  addProviderTiles(providers$OpenStreetMap.BlackAndWhite) %>% 
-  addPolylines(color = ~pal(`Percent Active`), weight = active$all / 100) %>% 
-  addLegend(pal = pal, values = ~`Percent Active`)
+  filter(e_dist_km < max_distance)
 
-## ---- out.width="100%"---------------------------------------------------
-# car dependent desire lines
+# interactive plot
+tmap_mode("view")
+tm_shape(active) +
+  tm_lines("Percent Active", palette = "RdYlBu", lwd = "all", scale = 9)
+
+## ---- echo=FALSE, eval=FALSE---------------------------------------------
+#  # old code - create with leaflet
+#  pal = colorBin(palette = "RdYlBu", domain = active$`Percent Active`, bins = c(0, 2, 4, 10, 15, 20, 30, 40, 90))
+#  leaflet(data = active) %>%
+#    addProviderTiles(providers$OpenStreetMap.BlackAndWhite) %>%
+#    addPolylines(color = ~pal(`Percent Active`), weight = active$all / 100) %>%
+#    addLegend(pal = pal, values = ~`Percent Active`)
+#  
+#  pal = colorBin(palette = "RdYlBu", domain = car_dependent$`Percent Active`, bins = c(0, 20, 40, 60, 80, 100), reverse = TRUE)
+#  leaflet(data = car_dependent) %>%
+#    addProviderTiles(providers$OpenStreetMap.BlackAndWhite) %>%
+#    addPolylines(color = ~pal(`Percent Drive`), weight = active$all / 100) %>%
+#    addLegend(pal = pal, values = ~`Percent Drive`)
+
+## ---- out.width="30%"----------------------------------------------------
+# Create car dependent desire lines
 car_dependent = lines_all %>% 
   mutate(`Percent Drive` = (car_driver) / all * 100) %>% 
-  filter(e_dist_km < 5)
-pal = colorBin(palette = "RdYlBu", domain = car_dependent$`Percent Active`, bins = c(0, 20, 40, 60, 80, 100), reverse = TRUE)
-leaflet(data = car_dependent) %>% 
-  addProviderTiles(providers$OpenStreetMap.BlackAndWhite) %>% 
-  addPolylines(color = ~pal(`Percent Drive`), weight = active$all / 100) %>% 
-  addLegend(pal = pal, values = ~`Percent Drive`)
+  filter(e_dist_km < max_distance)
+tm_shape(car_dependent) +
+  tm_lines("Percent Drive", palette = "-RdYlBu", lwd = "all", scale = 9)
+
+## ---- echo=FALSE, out.width="90%"----------------------------------------
+# u = "https://raw.githubusercontent.com/npct/pct-team/master/flow-model/flow-diag2.png"
+# f = "vignettes/flow-diag2.png"
+# download.file(u, f)
+# knitr::include_graphics("flow-diag2.png")
+knitr::include_graphics("https://raw.githubusercontent.com/npct/pct-team/master/flow-model/flow-diag2.png")
 
 ## ------------------------------------------------------------------------
 library(pct)
@@ -81,8 +113,8 @@ plot(z_highest_cycling$geometry, col = "red", add = TRUE)
 
 ## ----get routes----------------------------------------------------------
 # Aim: get top 5 cycle routes
-l_original = get_pct_lines("isle-of-wight")
-l_msoa = l_original %>% 
+l_original_msoa = get_pct_lines("isle-of-wight")
+l_msoa = l_original_msoa %>% 
   select(geo_code1, geo_code2, all, bicycle, car_driver, rf_avslope_perc, rf_dist_km)
 
 ## ---- echo=FALSE, warning=FALSE, fig.show='hold', fig.cap="Top 5 MSOA to MSOA desire lines with highest number of people cycling (left) and driving (right) in the Isle of Wight."----
@@ -159,9 +191,9 @@ l_msoa$pcycle_dutch = uptake_pct_godutch(
 ## ----dutch_pcycle, echo=FALSE, warning=FALSE, fig.show='hold', fig.cap="Percent cycling currently (left) and under a 'Go Dutch' scenario (right) in the Isle of Wight."----
 plot(l_msoa["pcycle"], lwd = l_msoa$all / mean(l_msoa$all), breaks = c(0, 5, 10, 20, 50))
 plot(l_msoa["pcycle_dutch"], lwd = l_msoa$all / mean(l_msoa$all), breaks = c(0, 5, 10, 20, 50))
-# cor(l_original$dutch_slc / l_original$all, l_msoa$pcycle_dutch)
-# cor(l_original$govtarget_slc / l_original$all, l_msoa$pcycle_govtarget)
-# plot(l_original$dutch_slc / l_original$all, l_msoa$pcycle_dutch)
+# cor(l_original_msoa$dutch_slc / l_original_msoa$all, l_msoa$pcycle_dutch)
+# cor(l_original_msoa$govtarget_slc / l_original_msoa$all, l_msoa$pcycle_govtarget)
+# plot(l_original_msoa$dutch_slc / l_original_msoa$all, l_msoa$pcycle_dutch)
 
 ## ------------------------------------------------------------------------
 library(stplanr)
@@ -176,9 +208,8 @@ l_top = l_msoa %>%
 
 ## ---- echo=FALSE---------------------------------------------------------
 r_top = sf::read_sf("https://github.com/ITSLeeds/pct/releases/download/0.0.1/r_top.geojson")
-leaflet() %>% 
-  addTiles() %>% 
-  addPolylines(data = r_top)
+tm_shape(r_top) +
+  tm_lines(lwd = 5)
 
 ## ---- echo=FALSE, eval=FALSE---------------------------------------------
 #  r_cs = stplanr::line2route(l_top)
@@ -191,14 +222,17 @@ route_data = sf::st_sf(wight_lines_30, geometry = wight_routes_30$geometry)
 
 ## ---- echo=FALSE, message=FALSE------------------------------------------
 rnet_walk = overline2(x = route_data, "foot")
-leaflet() %>% 
-  addTiles() %>% 
-  addPolylines(data = rnet_walk, weight = rnet_walk$foot / mean(rnet_walk$foot) * 5)
+tm_shape(rnet_walk) +
+  tm_lines(lwd = "foot", scale = 9)
+
+## ---- eval=FALSE, echo=FALSE---------------------------------------------
+#  rnet_school = get_pct_rnet(region = "isle-of-wight", purpose = "school")
+#  plot(rnet_school)
 
 ## ---- echo=FALSE, eval=FALSE---------------------------------------------
 #  # Demo PCT Analysis#
 #  # Make a commuting quiet route network for Isle of Wight
-#  # and combine it with the travle to school route network
+#  # and combine it with the travel to school route network
 #  
 #  # Step 1: Load Library
 #  library(tidyverse)
@@ -237,11 +271,11 @@ leaflet() %>%
 #  plot(rnet_commute["bicycle"])
 #  
 #  # Combine commuting and travel to schools
-#  rnet_school <- rnet_school %>%
+#  rnet_school = rnet_school %>%
 #    select(dutch_slc)
-#  rnet_commute <- rnet_commute %>%
+#  rnet_commute = rnet_commute %>%
 #    select(dutch_slc)
-#  rnet_commute$bicycle <- NULL
+#  rnet_commute$bicycle = NULL
 #  
 #  
 #  rnet_both = rbind(rnet_commute, rnet_school)
